==> django-simpletask-0.3.5.tar.gz: django-simpletask-0.3.5/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-simpletask",
    version="0.3.5",
    description="Django application provides simple task model, admin, server services and client service.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="zencore",
    author_email="dobetter@zencore.cn",
    url="https://github.com/zencore-cn/zencore-issues",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django abstract model", "django simple task"],
    install_requires=requires,
    packages=find_packages(".", exclude=["django_simpletask_example", "django_simpletask_example.migrations", "django_simpletask_demo"]),
    py_modules=["django_simpletask_engine"],
    zip_safe=False,
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "django-simpletask-engine = django_simpletask_engine:application",
        ],
    },
)

==> django-simpletask-0.3.6.tar.gz: django-simpletask-0.3.6/setup.py <==
# -*- coding: utf-8 -*-
from json.tool import main
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-simpletask",
    version="0.3.6",
    description="Django application provides simple task model, admin, server services and client service.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Zhang XianWei",
    author_email="zhangxianwei@zencore.cn",
    maintainer="Zhang XianWei",
    maintainer_email="zhangxianwei@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django abstract model", "django simple task"],
    install_requires=requires,
    packages=find_packages(
        ".",
        exclude=[
            "django_simpletask_example",
            "django_simpletask_example.migrations",
            "django_simpletask_demo",
        ],
    ),
    py_modules=["django_simpletask_engine"],
    zip_safe=False,
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "django-simpletask-engine = django_simpletask_engine:application",
        ],
    },
)
